#ifndef NT2_INCLUDE_CONSTANTS_REAL_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_REAL_HPP_INCLUDED

#include <nt2/constant/include/constants/real.hpp>

#endif
